RIPE Atlas Cousteau
===================

|Documentation| |PYPI Version| |Python Versions| |Python Implementations| |Python Format|

A Python wrapper around the RIPE ATLAS API.

Installation
------------

$ pip install ripe.atlas.cousteau

Docs
----
Complete documentation can be found on `Read the Docs`_.

.. _Read the Docs: http://ripe-atlas-cousteau.readthedocs.org/en/latest/

Name
----
But why `Cousteau`_? The RIPE Atlas team decided to name all of its
modules after explorers, and this is not an exception :)

.. _Cousteau: http://en.wikipedia.org/wiki/Jacques_Cousteau
.. |PYPI Version| image:: https://img.shields.io/pypi/v/ripe.atlas.cousteau.svg
   :target: https://pypi.org/project/ripe.atlas.cousteau/
.. |Python Versions| image:: https://img.shields.io/pypi/pyversions/ripe.atlas.cousteau.svg
.. |Python Implementations| image:: https://img.shields.io/pypi/implementation/ripe.atlas.cousteau.svg
.. |Python Format| image:: https://img.shields.io/pypi/format/ripe.atlas.cousteau.svg
.. |Documentation| image:: https://readthedocs.org/projects/ripe-atlas-cousteau/badge/?version=latest
   :target: https://ripe-atlas-cousteau.readthedocs.org/en/latest/?badge=latest

